@@ -6,12 +6,13 @@
 
 #include <bonobo-activation/bonobo-activation.h>
 #include <bonobo-activation/bonobo-activation-private.h>
+#include <libbonobo.h>
 #include "activation-server/server.h"
 
 #include "empty.h"
 #include "plugin.h"
 
-#define TOTAL_TEST_SCORE 16
+#define TOTAL_TEST_SCORE 17
 
 CORBA_Object name_service = CORBA_OBJECT_NIL;
 
@@ -181,6 +182,18 @@ race_empty (CORBA_Environment *ev)
                 g_main_context_iteration (NULL, TRUE);
 }
 
+static void
+listener_cb (BonoboListener *listener,
+             const char *event_name,
+             const CORBA_any *any,
+             CORBA_Environment *ev,
+             gpointer user_data)
+{
+        g_message ("Activation callback successfully called on %s",
+                   bonobo_event_subtype (event_name));
+}
+
+
 int
 main (int argc, char *argv[])
 {
@@ -192,6 +205,9 @@ main (int argc, char *argv[])
         char *query;
         int   i;
         GTimer *timer = g_timer_new ();
+	Bonobo_EventSource event_source;
+	
+        g_thread_init (NULL);
 
 	CORBA_exception_init (&ev);
 
@@ -199,9 +215,25 @@ main (int argc, char *argv[])
                 bonobo_activation_username_get (),
                 bonobo_activation_hostname_get ());
 
-	bonobo_activation_init (argc, argv);
+	bonobo_init (&argc, argv);
 /*      putenv("Bonobo_BARRIER_INIT=1"); */
 
+
+	event_source = bonobo_activation_activate_from_id
+                ("OAFIID:Bonobo_Activation_EventSource", 0, NULL, &ev);
+        if (event_source != CORBA_OBJECT_NIL) {
+		passed++;
+		fprintf (stderr, "PASSED %d of %d: Activation event source okay\n",
+                         passed + failed, TOTAL_TEST_SCORE);
+   	        bonobo_event_source_client_add_listener (event_source, listener_cb,
+                                                         "Bonobo/ObjectDirectory", &ev, NULL);
+        } else {
+		failed++;
+		fprintf (stderr, "FAILED %d of %d: Activation event source not found\n",
+                         passed + failed, TOTAL_TEST_SCORE);
+	}
+
+
         race_base_init ();
 
         sort_by[0] = "prefer_by_list_order(iid, ["
@@ -271,14 +303,18 @@ main (int argc, char *argv[])
         /*
          *    We wait to see if the server (sever)
          * timeout is mis-behaving [ at this stage we
-         * havn't registered anything with the server ]
+         * have not registered anything with the server ]
          */
         fprintf (stderr, "Waiting to see if the server erroneously quits\n");
-        sleep (SERVER_IDLE_QUIT_TIMEOUT * 2 / 1000);
+        g_usleep (SERVER_IDLE_QUIT_TIMEOUT * 2 * 1000);
         g_assert (ORBit_small_get_connection_status (ac) ==
                   ORBIT_CONNECTION_CONNECTED);
 
         race_empty (&ev);
+	
+	
+	
+	
 
 	obj = bonobo_activation_activate_from_id ("OAFIID:Empty:19991025", 0, NULL, &ev);
         if (test_object (obj, &ev, "from id") && test_empty (obj, &ev, "from id")) {
@@ -414,7 +450,7 @@ main (int argc, char *argv[])
                  passed == TOTAL_TEST_SCORE? "All": "some failures");
 
         if (passed < (TOTAL_TEST_SCORE * 2 / 3)) {
-                fprintf (stderr, "It looks like you havn't installed broken.server "
+                fprintf (stderr, "It looks like you have not installed broken.server "
                          "into ${prefix}/share/bonobo-activation/, this must be done "
                          "by hand to avoid problems with normal operation.\n");
 		fprintf (stderr, "Another possibility is that you failed to kill "
@@ -423,11 +459,14 @@ main (int argc, char *argv[])
 
         if (name_service != CORBA_OBJECT_NIL)
                 CORBA_Object_release (name_service, &ev);
+        
+        if (event_source != CORBA_OBJECT_NIL)
+		CORBA_Object_release (event_source, &ev);
 
 	CORBA_exception_free (&ev);
 
         if (passed == TOTAL_TEST_SCORE) {
-                if (bonobo_activation_debug_shutdown ()) {
+                if (bonobo_debug_shutdown ()) {
                         return 0;
                 } else {
                         return 1;
